# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Token(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'token_id': 'int',
        'issued': 'int',
        'expire': 'int',
        'token': 'str',
        'user_id': 'str',
        'is_revoked': 'int'
    }

    attribute_map = {
        'token_id': 'tokenId',
        'issued': 'issued',
        'expire': 'expire',
        'token': 'token',
        'user_id': 'userId',
        'is_revoked': 'isRevoked'
    }

    def __init__(self, token_id=None, issued=None, expire=None, token=None, user_id=None, is_revoked=None):  # noqa: E501
        """Token - a model defined in Swagger"""  # noqa: E501

        self._token_id = None
        self._issued = None
        self._expire = None
        self._token = None
        self._user_id = None
        self._is_revoked = None
        self.discriminator = None

        if token_id is not None:
            self.token_id = token_id
        if issued is not None:
            self.issued = issued
        if expire is not None:
            self.expire = expire
        if token is not None:
            self.token = token
        if user_id is not None:
            self.user_id = user_id
        if is_revoked is not None:
            self.is_revoked = is_revoked

    @property
    def token_id(self):
        """Gets the token_id of this Token.  # noqa: E501


        :return: The token_id of this Token.  # noqa: E501
        :rtype: int
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this Token.


        :param token_id: The token_id of this Token.  # noqa: E501
        :type: int
        """

        self._token_id = token_id

    @property
    def issued(self):
        """Gets the issued of this Token.  # noqa: E501


        :return: The issued of this Token.  # noqa: E501
        :rtype: int
        """
        return self._issued

    @issued.setter
    def issued(self, issued):
        """Sets the issued of this Token.


        :param issued: The issued of this Token.  # noqa: E501
        :type: int
        """

        self._issued = issued

    @property
    def expire(self):
        """Gets the expire of this Token.  # noqa: E501


        :return: The expire of this Token.  # noqa: E501
        :rtype: int
        """
        return self._expire

    @expire.setter
    def expire(self, expire):
        """Sets the expire of this Token.


        :param expire: The expire of this Token.  # noqa: E501
        :type: int
        """

        self._expire = expire

    @property
    def token(self):
        """Gets the token of this Token.  # noqa: E501


        :return: The token of this Token.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Token.


        :param token: The token of this Token.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def user_id(self):
        """Gets the user_id of this Token.  # noqa: E501


        :return: The user_id of this Token.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Token.


        :param user_id: The user_id of this Token.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def is_revoked(self):
        """Gets the is_revoked of this Token.  # noqa: E501


        :return: The is_revoked of this Token.  # noqa: E501
        :rtype: int
        """
        return self._is_revoked

    @is_revoked.setter
    def is_revoked(self, is_revoked):
        """Sets the is_revoked of this Token.


        :param is_revoked: The is_revoked of this Token.  # noqa: E501
        :type: int
        """

        self._is_revoked = is_revoked

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Token):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExperimentEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'best_model_id': 'str',
        'input_data_uri': 'str',
        'experiment_id': 'str',
        'experiment_name': 'str',
        'experiment_description': 'str',
        'notebook_json': 'str',
        'notebook_url': 'str',
        'zeppelin_id': 'str',
        'model_history_id': 'str',
        'last_updated': 'int'
    }

    attribute_map = {
        'best_model_id': 'bestModelId',
        'input_data_uri': 'inputDataUri',
        'experiment_id': 'experimentId',
        'experiment_name': 'experimentName',
        'experiment_description': 'experimentDescription',
        'notebook_json': 'notebookJson',
        'notebook_url': 'notebookUrl',
        'zeppelin_id': 'zeppelinId',
        'model_history_id': 'modelHistoryId',
        'last_updated': 'lastUpdated'
    }

    def __init__(self, best_model_id=None, input_data_uri=None, experiment_id=None, experiment_name=None, experiment_description=None, notebook_json=None, notebook_url=None, zeppelin_id=None, model_history_id=None, last_updated=None):  # noqa: E501
        """ExperimentEntity - a model defined in Swagger"""  # noqa: E501

        self._best_model_id = None
        self._input_data_uri = None
        self._experiment_id = None
        self._experiment_name = None
        self._experiment_description = None
        self._notebook_json = None
        self._notebook_url = None
        self._zeppelin_id = None
        self._model_history_id = None
        self._last_updated = None
        self.discriminator = None

        if best_model_id is not None:
            self.best_model_id = best_model_id
        if input_data_uri is not None:
            self.input_data_uri = input_data_uri
        if experiment_id is not None:
            self.experiment_id = experiment_id
        if experiment_name is not None:
            self.experiment_name = experiment_name
        if experiment_description is not None:
            self.experiment_description = experiment_description
        if notebook_json is not None:
            self.notebook_json = notebook_json
        if notebook_url is not None:
            self.notebook_url = notebook_url
        if zeppelin_id is not None:
            self.zeppelin_id = zeppelin_id
        if model_history_id is not None:
            self.model_history_id = model_history_id
        if last_updated is not None:
            self.last_updated = last_updated

    @property
    def best_model_id(self):
        """Gets the best_model_id of this ExperimentEntity.  # noqa: E501

        GUID of the best selected model in an experiment  # noqa: E501

        :return: The best_model_id of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._best_model_id

    @best_model_id.setter
    def best_model_id(self, best_model_id):
        """Sets the best_model_id of this ExperimentEntity.

        GUID of the best selected model in an experiment  # noqa: E501

        :param best_model_id: The best_model_id of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._best_model_id = best_model_id

    @property
    def input_data_uri(self):
        """Gets the input_data_uri of this ExperimentEntity.  # noqa: E501

        Input data URI  # noqa: E501

        :return: The input_data_uri of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._input_data_uri

    @input_data_uri.setter
    def input_data_uri(self, input_data_uri):
        """Sets the input_data_uri of this ExperimentEntity.

        Input data URI  # noqa: E501

        :param input_data_uri: The input_data_uri of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._input_data_uri = input_data_uri

    @property
    def experiment_id(self):
        """Gets the experiment_id of this ExperimentEntity.  # noqa: E501

        GUID of the experiment  # noqa: E501

        :return: The experiment_id of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._experiment_id

    @experiment_id.setter
    def experiment_id(self, experiment_id):
        """Sets the experiment_id of this ExperimentEntity.

        GUID of the experiment  # noqa: E501

        :param experiment_id: The experiment_id of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._experiment_id = experiment_id

    @property
    def experiment_name(self):
        """Gets the experiment_name of this ExperimentEntity.  # noqa: E501

        Experiment's name  # noqa: E501

        :return: The experiment_name of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._experiment_name

    @experiment_name.setter
    def experiment_name(self, experiment_name):
        """Sets the experiment_name of this ExperimentEntity.

        Experiment's name  # noqa: E501

        :param experiment_name: The experiment_name of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._experiment_name = experiment_name

    @property
    def experiment_description(self):
        """Gets the experiment_description of this ExperimentEntity.  # noqa: E501

        Experiment's description  # noqa: E501

        :return: The experiment_description of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._experiment_description

    @experiment_description.setter
    def experiment_description(self, experiment_description):
        """Sets the experiment_description of this ExperimentEntity.

        Experiment's description  # noqa: E501

        :param experiment_description: The experiment_description of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._experiment_description = experiment_description

    @property
    def notebook_json(self):
        """Gets the notebook_json of this ExperimentEntity.  # noqa: E501

        The associated Zeppelin notebook JSON string  # noqa: E501

        :return: The notebook_json of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._notebook_json

    @notebook_json.setter
    def notebook_json(self, notebook_json):
        """Sets the notebook_json of this ExperimentEntity.

        The associated Zeppelin notebook JSON string  # noqa: E501

        :param notebook_json: The notebook_json of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._notebook_json = notebook_json

    @property
    def notebook_url(self):
        """Gets the notebook_url of this ExperimentEntity.  # noqa: E501

        URL of the associated Zeppelin notebook  # noqa: E501

        :return: The notebook_url of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._notebook_url

    @notebook_url.setter
    def notebook_url(self, notebook_url):
        """Sets the notebook_url of this ExperimentEntity.

        URL of the associated Zeppelin notebook  # noqa: E501

        :param notebook_url: The notebook_url of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._notebook_url = notebook_url

    @property
    def zeppelin_id(self):
        """Gets the zeppelin_id of this ExperimentEntity.  # noqa: E501

        Zeppelin ID  # noqa: E501

        :return: The zeppelin_id of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._zeppelin_id

    @zeppelin_id.setter
    def zeppelin_id(self, zeppelin_id):
        """Sets the zeppelin_id of this ExperimentEntity.

        Zeppelin ID  # noqa: E501

        :param zeppelin_id: The zeppelin_id of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._zeppelin_id = zeppelin_id

    @property
    def model_history_id(self):
        """Gets the model_history_id of this ExperimentEntity.  # noqa: E501

        Id of the model history / workspace  # noqa: E501

        :return: The model_history_id of this ExperimentEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_history_id

    @model_history_id.setter
    def model_history_id(self, model_history_id):
        """Sets the model_history_id of this ExperimentEntity.

        Id of the model history / workspace  # noqa: E501

        :param model_history_id: The model_history_id of this ExperimentEntity.  # noqa: E501
        :type: str
        """

        self._model_history_id = model_history_id

    @property
    def last_updated(self):
        """Gets the last_updated of this ExperimentEntity.  # noqa: E501

        Indicates the time when experiment was last updated  # noqa: E501

        :return: The last_updated of this ExperimentEntity.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this ExperimentEntity.

        Indicates the time when experiment was last updated  # noqa: E501

        :param last_updated: The last_updated of this ExperimentEntity.  # noqa: E501
        :type: int
        """

        self._last_updated = last_updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExperimentEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from skil_client.api.default_api import DefaultApi

# import ApiClient
from skil_client.api_client import ApiClient
from skil_client.configuration import Configuration
# import models into sdk package
from skil_client.models.accumulated_results import AccumulatedResults
from skil_client.models.add_credentials_request import AddCredentialsRequest
from skil_client.models.add_example_request import AddExampleRequest
from skil_client.models.add_model_history_request import AddModelHistoryRequest
from skil_client.models.add_resource_request import AddResourceRequest
from skil_client.models.aggregate_prediction import AggregatePrediction
from skil_client.models.auth_policy import AuthPolicy
from skil_client.models.azure_storage_resource_details import AzureStorageResourceDetails
from skil_client.models.base64_nd_array_body import Base64NDArrayBody
from skil_client.models.base64_nd_array_body_knn import Base64NDArrayBodyKNN
from skil_client.models.batch_csv_record import BatchCSVRecord
from skil_client.models.batch_record import BatchRecord
from skil_client.models.best_model import BestModel
from skil_client.models.change_password_request import ChangePasswordRequest
from skil_client.models.classification_result import ClassificationResult
from skil_client.models.create_deployment_request import CreateDeploymentRequest
from skil_client.models.create_job_request import CreateJobRequest
from skil_client.models.data_proc_resource_details import DataProcResourceDetails
from skil_client.models.deployment_objects import DeploymentObjects
from skil_client.models.deployment_response import DeploymentResponse
from skil_client.models.detected_object import DetectedObject
from skil_client.models.detection_result import DetectionResult
from skil_client.models.download_output_file_request import DownloadOutputFileRequest
from skil_client.models.emr_resource_details import EMRResourceDetails
from skil_client.models.evaluation_results_entity import EvaluationResultsEntity
from skil_client.models.example_entity import ExampleEntity
from skil_client.models.experiment_entity import ExperimentEntity
from skil_client.models.feedback_response import FeedbackResponse
from skil_client.models.file_upload import FileUpload
from skil_client.models.file_upload_list import FileUploadList
from skil_client.models.google_storage_resource_details import GoogleStorageResourceDetails
from skil_client.models.hdfs_resource_details import HDFSResourceDetails
from skil_client.models.hd_insight_resource_details import HDInsightResourceDetails
from skil_client.models.ind_array import INDArray
from skil_client.models.image_transform_process import ImageTransformProcess
from skil_client.models.import_model_request import ImportModelRequest
from skil_client.models.inline_response200 import InlineResponse200
from skil_client.models.job_entity import JobEntity
from skil_client.models.json_array_response import JsonArrayResponse
from skil_client.models.log_batch import LogBatch
from skil_client.models.log_request import LogRequest
from skil_client.models.login_request import LoginRequest
from skil_client.models.login_response import LoginResponse
from skil_client.models.meta_data import MetaData
from skil_client.models.minibatch_entity import MinibatchEntity
from skil_client.models.model_entity import ModelEntity
from skil_client.models.model_feed_back_request import ModelFeedBackRequest
from skil_client.models.model_history_entity import ModelHistoryEntity
from skil_client.models.model_instance_entity import ModelInstanceEntity
from skil_client.models.model_response import ModelResponse
from skil_client.models.model_status import ModelStatus
from skil_client.models.multi_class_classification_result import MultiClassClassificationResult
from skil_client.models.multi_predict_request import MultiPredictRequest
from skil_client.models.multi_predict_response import MultiPredictResponse
from skil_client.models.nearest_neighbor_request import NearestNeighborRequest
from skil_client.models.nearest_neighbors_result import NearestNeighborsResult
from skil_client.models.nearest_neighbors_results import NearestNeighborsResults
from skil_client.models.new_deployment import NewDeployment
from skil_client.models.prediction import Prediction
from skil_client.models.resource import Resource
from skil_client.models.resource_credentials import ResourceCredentials
from skil_client.models.resource_group import ResourceGroup
from skil_client.models.retraining_status import RetrainingStatus
from skil_client.models.revisions_written import RevisionsWritten
from skil_client.models.role import Role
from skil_client.models.rollback_status import RollbackStatus
from skil_client.models.s3_resource_details import S3ResourceDetails
from skil_client.models.set_state import SetState
from skil_client.models.single_csv_record import SingleCSVRecord
from skil_client.models.single_record import SingleRecord
from skil_client.models.token import Token
from skil_client.models.token_generate_request import TokenGenerateRequest
from skil_client.models.transform_process import TransformProcess
from skil_client.models.update_best_model import UpdateBestModel
from skil_client.models.user import User
from skil_client.models.yarn_resource_details import YARNResourceDetails



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GoogleStorageResourceDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_class': 'str',
        'resource_id': 'int',
        'type': 'str',
        'sub_type': 'str',
        'project_id': 'str',
        'bucket_name': 'str'
    }

    attribute_map = {
        '_class': '@class',
        'resource_id': 'resourceId',
        'type': 'type',
        'sub_type': 'subType',
        'project_id': 'projectId',
        'bucket_name': 'bucketName'
    }

    def __init__(self, _class='io.skymind.resource.model.subtypes.storage.GoogleStorageResourceDetails', resource_id=None, type=None, sub_type=None, project_id=None, bucket_name=None):  # noqa: E501
        """GoogleStorageResourceDetails - a model defined in Swagger"""  # noqa: E501

        self.__class = None
        self._resource_id = None
        self._type = None
        self._sub_type = None
        self._project_id = None
        self._bucket_name = None
        self.discriminator = None

        if _class is not None:
            self._class = _class
        if resource_id is not None:
            self.resource_id = resource_id
        if type is not None:
            self.type = type
        if sub_type is not None:
            self.sub_type = sub_type
        if project_id is not None:
            self.project_id = project_id
        if bucket_name is not None:
            self.bucket_name = bucket_name

    @property
    def _class(self):
        """Gets the _class of this GoogleStorageResourceDetails.  # noqa: E501


        :return: The _class of this GoogleStorageResourceDetails.  # noqa: E501
        :rtype: str
        """
        return self.__class

    @_class.setter
    def _class(self, _class):
        """Sets the _class of this GoogleStorageResourceDetails.


        :param _class: The _class of this GoogleStorageResourceDetails.  # noqa: E501
        :type: str
        """

        self.__class = _class

    @property
    def resource_id(self):
        """Gets the resource_id of this GoogleStorageResourceDetails.  # noqa: E501

        ID of the resource  # noqa: E501

        :return: The resource_id of this GoogleStorageResourceDetails.  # noqa: E501
        :rtype: int
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this GoogleStorageResourceDetails.

        ID of the resource  # noqa: E501

        :param resource_id: The resource_id of this GoogleStorageResourceDetails.  # noqa: E501
        :type: int
        """

        self._resource_id = resource_id

    @property
    def type(self):
        """Gets the type of this GoogleStorageResourceDetails.  # noqa: E501

        Resource type  # noqa: E501

        :return: The type of this GoogleStorageResourceDetails.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GoogleStorageResourceDetails.

        Resource type  # noqa: E501

        :param type: The type of this GoogleStorageResourceDetails.  # noqa: E501
        :type: str
        """
        allowed_values = ["STORAGE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def sub_type(self):
        """Gets the sub_type of this GoogleStorageResourceDetails.  # noqa: E501

        Resource subtype  # noqa: E501

        :return: The sub_type of this GoogleStorageResourceDetails.  # noqa: E501
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this GoogleStorageResourceDetails.

        Resource subtype  # noqa: E501

        :param sub_type: The sub_type of this GoogleStorageResourceDetails.  # noqa: E501
        :type: str
        """
        allowed_values = ["GoogleStorage"]  # noqa: E501
        if sub_type not in allowed_values:
            raise ValueError(
                "Invalid value for `sub_type` ({0}), must be one of {1}"  # noqa: E501
                .format(sub_type, allowed_values)
            )

        self._sub_type = sub_type

    @property
    def project_id(self):
        """Gets the project_id of this GoogleStorageResourceDetails.  # noqa: E501

        Project ID  # noqa: E501

        :return: The project_id of this GoogleStorageResourceDetails.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GoogleStorageResourceDetails.

        Project ID  # noqa: E501

        :param project_id: The project_id of this GoogleStorageResourceDetails.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def bucket_name(self):
        """Gets the bucket_name of this GoogleStorageResourceDetails.  # noqa: E501

        Name of the storage bucket  # noqa: E501

        :return: The bucket_name of this GoogleStorageResourceDetails.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this GoogleStorageResourceDetails.

        Name of the storage bucket  # noqa: E501

        :param bucket_name: The bucket_name of this GoogleStorageResourceDetails.  # noqa: E501
        :type: str
        """

        self._bucket_name = bucket_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GoogleStorageResourceDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class JobEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'int',
        'job_type': 'str',
        'compute_resource_id': 'int',
        'storage_resource_id': 'int',
        'job_args': 'str',
        'run_id': 'str',
        'status': 'str',
        'output_file_name': 'str'
    }

    attribute_map = {
        'job_id': 'jobId',
        'job_type': 'jobType',
        'compute_resource_id': 'computeResourceId',
        'storage_resource_id': 'storageResourceId',
        'job_args': 'jobArgs',
        'run_id': 'runId',
        'status': 'status',
        'output_file_name': 'outputFileName'
    }

    def __init__(self, job_id=None, job_type=None, compute_resource_id=None, storage_resource_id=None, job_args=None, run_id=None, status=None, output_file_name=None):  # noqa: E501
        """JobEntity - a model defined in Swagger"""  # noqa: E501

        self._job_id = None
        self._job_type = None
        self._compute_resource_id = None
        self._storage_resource_id = None
        self._job_args = None
        self._run_id = None
        self._status = None
        self._output_file_name = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if job_type is not None:
            self.job_type = job_type
        if compute_resource_id is not None:
            self.compute_resource_id = compute_resource_id
        if storage_resource_id is not None:
            self.storage_resource_id = storage_resource_id
        if job_args is not None:
            self.job_args = job_args
        if run_id is not None:
            self.run_id = run_id
        if status is not None:
            self.status = status
        if output_file_name is not None:
            self.output_file_name = output_file_name

    @property
    def job_id(self):
        """Gets the job_id of this JobEntity.  # noqa: E501

        Job ID  # noqa: E501

        :return: The job_id of this JobEntity.  # noqa: E501
        :rtype: int
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobEntity.

        Job ID  # noqa: E501

        :param job_id: The job_id of this JobEntity.  # noqa: E501
        :type: int
        """

        self._job_id = job_id

    @property
    def job_type(self):
        """Gets the job_type of this JobEntity.  # noqa: E501

        Whether a job is for training or inference  # noqa: E501

        :return: The job_type of this JobEntity.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this JobEntity.

        Whether a job is for training or inference  # noqa: E501

        :param job_type: The job_type of this JobEntity.  # noqa: E501
        :type: str
        """
        allowed_values = ["TRAINING", "INFERENCE"]  # noqa: E501
        if job_type not in allowed_values:
            raise ValueError(
                "Invalid value for `job_type` ({0}), must be one of {1}"  # noqa: E501
                .format(job_type, allowed_values)
            )

        self._job_type = job_type

    @property
    def compute_resource_id(self):
        """Gets the compute_resource_id of this JobEntity.  # noqa: E501

        Compute resource ID  # noqa: E501

        :return: The compute_resource_id of this JobEntity.  # noqa: E501
        :rtype: int
        """
        return self._compute_resource_id

    @compute_resource_id.setter
    def compute_resource_id(self, compute_resource_id):
        """Sets the compute_resource_id of this JobEntity.

        Compute resource ID  # noqa: E501

        :param compute_resource_id: The compute_resource_id of this JobEntity.  # noqa: E501
        :type: int
        """

        self._compute_resource_id = compute_resource_id

    @property
    def storage_resource_id(self):
        """Gets the storage_resource_id of this JobEntity.  # noqa: E501

        Storage resource ID  # noqa: E501

        :return: The storage_resource_id of this JobEntity.  # noqa: E501
        :rtype: int
        """
        return self._storage_resource_id

    @storage_resource_id.setter
    def storage_resource_id(self, storage_resource_id):
        """Sets the storage_resource_id of this JobEntity.

        Storage resource ID  # noqa: E501

        :param storage_resource_id: The storage_resource_id of this JobEntity.  # noqa: E501
        :type: int
        """

        self._storage_resource_id = storage_resource_id

    @property
    def job_args(self):
        """Gets the job_args of this JobEntity.  # noqa: E501

        Job arguments  # noqa: E501

        :return: The job_args of this JobEntity.  # noqa: E501
        :rtype: str
        """
        return self._job_args

    @job_args.setter
    def job_args(self, job_args):
        """Sets the job_args of this JobEntity.

        Job arguments  # noqa: E501

        :param job_args: The job_args of this JobEntity.  # noqa: E501
        :type: str
        """

        self._job_args = job_args

    @property
    def run_id(self):
        """Gets the run_id of this JobEntity.  # noqa: E501

        Job run ID  # noqa: E501

        :return: The run_id of this JobEntity.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this JobEntity.

        Job run ID  # noqa: E501

        :param run_id: The run_id of this JobEntity.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def status(self):
        """Gets the status of this JobEntity.  # noqa: E501

        Job's status  # noqa: E501

        :return: The status of this JobEntity.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobEntity.

        Job's status  # noqa: E501

        :param status: The status of this JobEntity.  # noqa: E501
        :type: str
        """
        allowed_values = ["PENDING", "RUNNING", "CONTINUE", "COMPLETED", "CANCELLED", "FAILED", "INTERRUPTED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def output_file_name(self):
        """Gets the output_file_name of this JobEntity.  # noqa: E501

        Output file name  # noqa: E501

        :return: The output_file_name of this JobEntity.  # noqa: E501
        :rtype: str
        """
        return self._output_file_name

    @output_file_name.setter
    def output_file_name(self, output_file_name):
        """Sets the output_file_name of this JobEntity.

        Output file name  # noqa: E501

        :param output_file_name: The output_file_name of this JobEntity.  # noqa: E501
        :type: str
        """

        self._output_file_name = output_file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FileUpload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'file_name': 'str',
        'status': 'str',
        'type': 'str',
        'path': 'str',
        'file_content': 'str'
    }

    attribute_map = {
        'key': 'key',
        'file_name': 'fileName',
        'status': 'status',
        'type': 'type',
        'path': 'path',
        'file_content': 'fileContent'
    }

    def __init__(self, key=None, file_name=None, status=None, type=None, path=None, file_content=None):  # noqa: E501
        """FileUpload - a model defined in Swagger"""  # noqa: E501

        self._key = None
        self._file_name = None
        self._status = None
        self._type = None
        self._path = None
        self._file_content = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if file_name is not None:
            self.file_name = file_name
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if path is not None:
            self.path = path
        if file_content is not None:
            self.file_content = file_content

    @property
    def key(self):
        """Gets the key of this FileUpload.  # noqa: E501


        :return: The key of this FileUpload.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this FileUpload.


        :param key: The key of this FileUpload.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def file_name(self):
        """Gets the file_name of this FileUpload.  # noqa: E501


        :return: The file_name of this FileUpload.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this FileUpload.


        :param file_name: The file_name of this FileUpload.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def status(self):
        """Gets the status of this FileUpload.  # noqa: E501


        :return: The status of this FileUpload.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FileUpload.


        :param status: The status of this FileUpload.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this FileUpload.  # noqa: E501


        :return: The type of this FileUpload.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FileUpload.


        :param type: The type of this FileUpload.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def path(self):
        """Gets the path of this FileUpload.  # noqa: E501


        :return: The path of this FileUpload.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this FileUpload.


        :param path: The path of this FileUpload.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def file_content(self):
        """Gets the file_content of this FileUpload.  # noqa: E501


        :return: The file_content of this FileUpload.  # noqa: E501
        :rtype: str
        """
        return self._file_content

    @file_content.setter
    def file_content(self, file_content):
        """Sets the file_content of this FileUpload.


        :param file_content: The file_content of this FileUpload.  # noqa: E501
        :type: str
        """

        self._file_content = file_content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileUpload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ModelInstanceEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'uri': 'str',
        'etl_json': 'str',
        'model_id': 'str',
        'model_labels': 'str',
        'input_formats': 'str',
        'created': 'int',
        'notebook_json': 'str',
        'eval_id': 'str',
        'model_name': 'str',
        'original_model_id': 'str',
        'model_version': 'str',
        'experiment_id': 'str'
    }

    attribute_map = {
        'uri': 'uri',
        'etl_json': 'etlJson',
        'model_id': 'modelId',
        'model_labels': 'modelLabels',
        'input_formats': 'inputFormats',
        'created': 'created',
        'notebook_json': 'notebookJson',
        'eval_id': 'evalId',
        'model_name': 'modelName',
        'original_model_id': 'originalModelId',
        'model_version': 'modelVersion',
        'experiment_id': 'experimentId'
    }

    def __init__(self, uri=None, etl_json=None, model_id=None, model_labels=None, input_formats=None, created=None, notebook_json=None, eval_id=None, model_name=None, original_model_id=None, model_version=None, experiment_id=None):  # noqa: E501
        """ModelInstanceEntity - a model defined in Swagger"""  # noqa: E501

        self._uri = None
        self._etl_json = None
        self._model_id = None
        self._model_labels = None
        self._input_formats = None
        self._created = None
        self._notebook_json = None
        self._eval_id = None
        self._model_name = None
        self._original_model_id = None
        self._model_version = None
        self._experiment_id = None
        self.discriminator = None

        if uri is not None:
            self.uri = uri
        if etl_json is not None:
            self.etl_json = etl_json
        if model_id is not None:
            self.model_id = model_id
        if model_labels is not None:
            self.model_labels = model_labels
        if input_formats is not None:
            self.input_formats = input_formats
        if created is not None:
            self.created = created
        if notebook_json is not None:
            self.notebook_json = notebook_json
        if eval_id is not None:
            self.eval_id = eval_id
        if model_name is not None:
            self.model_name = model_name
        if original_model_id is not None:
            self.original_model_id = original_model_id
        if model_version is not None:
            self.model_version = model_version
        if experiment_id is not None:
            self.experiment_id = experiment_id

    @property
    def uri(self):
        """Gets the uri of this ModelInstanceEntity.  # noqa: E501

        The model URI  # noqa: E501

        :return: The uri of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ModelInstanceEntity.

        The model URI  # noqa: E501

        :param uri: The uri of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def etl_json(self):
        """Gets the etl_json of this ModelInstanceEntity.  # noqa: E501

        The json string for the ETL (Extract, Transform and Load)  # noqa: E501

        :return: The etl_json of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._etl_json

    @etl_json.setter
    def etl_json(self, etl_json):
        """Sets the etl_json of this ModelInstanceEntity.

        The json string for the ETL (Extract, Transform and Load)  # noqa: E501

        :param etl_json: The etl_json of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._etl_json = etl_json

    @property
    def model_id(self):
        """Gets the model_id of this ModelInstanceEntity.  # noqa: E501

        GUID of the model.  # noqa: E501

        :return: The model_id of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this ModelInstanceEntity.

        GUID of the model.  # noqa: E501

        :param model_id: The model_id of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def model_labels(self):
        """Gets the model_labels of this ModelInstanceEntity.  # noqa: E501

        Comma-separated labels string for the model  # noqa: E501

        :return: The model_labels of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_labels

    @model_labels.setter
    def model_labels(self, model_labels):
        """Sets the model_labels of this ModelInstanceEntity.

        Comma-separated labels string for the model  # noqa: E501

        :param model_labels: The model_labels of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._model_labels = model_labels

    @property
    def input_formats(self):
        """Gets the input_formats of this ModelInstanceEntity.  # noqa: E501

        Format for the model input  # noqa: E501

        :return: The input_formats of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._input_formats

    @input_formats.setter
    def input_formats(self, input_formats):
        """Sets the input_formats of this ModelInstanceEntity.

        Format for the model input  # noqa: E501

        :param input_formats: The input_formats of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._input_formats = input_formats

    @property
    def created(self):
        """Gets the created of this ModelInstanceEntity.  # noqa: E501

        When the model was created  # noqa: E501

        :return: The created of this ModelInstanceEntity.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ModelInstanceEntity.

        When the model was created  # noqa: E501

        :param created: The created of this ModelInstanceEntity.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def notebook_json(self):
        """Gets the notebook_json of this ModelInstanceEntity.  # noqa: E501

        JSON string of the associated Zeppelin Notebook  # noqa: E501

        :return: The notebook_json of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._notebook_json

    @notebook_json.setter
    def notebook_json(self, notebook_json):
        """Sets the notebook_json of this ModelInstanceEntity.

        JSON string of the associated Zeppelin Notebook  # noqa: E501

        :param notebook_json: The notebook_json of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._notebook_json = notebook_json

    @property
    def eval_id(self):
        """Gets the eval_id of this ModelInstanceEntity.  # noqa: E501

        GUID for the model evaluation  # noqa: E501

        :return: The eval_id of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._eval_id

    @eval_id.setter
    def eval_id(self, eval_id):
        """Sets the eval_id of this ModelInstanceEntity.

        GUID for the model evaluation  # noqa: E501

        :param eval_id: The eval_id of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._eval_id = eval_id

    @property
    def model_name(self):
        """Gets the model_name of this ModelInstanceEntity.  # noqa: E501

        Model's name  # noqa: E501

        :return: The model_name of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this ModelInstanceEntity.

        Model's name  # noqa: E501

        :param model_name: The model_name of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def original_model_id(self):
        """Gets the original_model_id of this ModelInstanceEntity.  # noqa: E501

        Original GUID of the model (used for maintaining revisions of a particular model)  # noqa: E501

        :return: The original_model_id of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._original_model_id

    @original_model_id.setter
    def original_model_id(self, original_model_id):
        """Sets the original_model_id of this ModelInstanceEntity.

        Original GUID of the model (used for maintaining revisions of a particular model)  # noqa: E501

        :param original_model_id: The original_model_id of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._original_model_id = original_model_id

    @property
    def model_version(self):
        """Gets the model_version of this ModelInstanceEntity.  # noqa: E501

        Model version  # noqa: E501

        :return: The model_version of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """Sets the model_version of this ModelInstanceEntity.

        Model version  # noqa: E501

        :param model_version: The model_version of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._model_version = model_version

    @property
    def experiment_id(self):
        """Gets the experiment_id of this ModelInstanceEntity.  # noqa: E501

        GUID of the Experiment which is associated with the model.  # noqa: E501

        :return: The experiment_id of this ModelInstanceEntity.  # noqa: E501
        :rtype: str
        """
        return self._experiment_id

    @experiment_id.setter
    def experiment_id(self, experiment_id):
        """Sets the experiment_id of this ModelInstanceEntity.

        GUID of the Experiment which is associated with the model.  # noqa: E501

        :param experiment_id: The experiment_id of this ModelInstanceEntity.  # noqa: E501
        :type: str
        """

        self._experiment_id = experiment_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelInstanceEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EvaluationResultsEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'evaluation': 'str',
        'eval_name': 'str',
        'model_instance_id': 'str',
        'created': 'int',
        'f1': 'float',
        'precision': 'float',
        'recall': 'float',
        'accuracy': 'float',
        'rmse': 'float',
        'auc': 'float',
        'mean_absolute_error': 'float',
        'mean_relative_error': 'float',
        'r2': 'float',
        'eval_id': 'str',
        'eval_version': 'int',
        'binary_threshold': 'float',
        'binary_thresholds': 'str'
    }

    attribute_map = {
        'evaluation': 'evaluation',
        'eval_name': 'evalName',
        'model_instance_id': 'modelInstanceId',
        'created': 'created',
        'f1': 'f1',
        'precision': 'precision',
        'recall': 'recall',
        'accuracy': 'accuracy',
        'rmse': 'rmse',
        'auc': 'auc',
        'mean_absolute_error': 'meanAbsoluteError',
        'mean_relative_error': 'meanRelativeError',
        'r2': 'r2',
        'eval_id': 'evalId',
        'eval_version': 'evalVersion',
        'binary_threshold': 'binaryThreshold',
        'binary_thresholds': 'binaryThresholds'
    }

    def __init__(self, evaluation=None, eval_name=None, model_instance_id=None, created=None, f1=None, precision=None, recall=None, accuracy=None, rmse=None, auc=None, mean_absolute_error=None, mean_relative_error=None, r2=None, eval_id=None, eval_version=None, binary_threshold=None, binary_thresholds=None):  # noqa: E501
        """EvaluationResultsEntity - a model defined in Swagger"""  # noqa: E501

        self._evaluation = None
        self._eval_name = None
        self._model_instance_id = None
        self._created = None
        self._f1 = None
        self._precision = None
        self._recall = None
        self._accuracy = None
        self._rmse = None
        self._auc = None
        self._mean_absolute_error = None
        self._mean_relative_error = None
        self._r2 = None
        self._eval_id = None
        self._eval_version = None
        self._binary_threshold = None
        self._binary_thresholds = None
        self.discriminator = None

        if evaluation is not None:
            self.evaluation = evaluation
        if eval_name is not None:
            self.eval_name = eval_name
        if model_instance_id is not None:
            self.model_instance_id = model_instance_id
        if created is not None:
            self.created = created
        if f1 is not None:
            self.f1 = f1
        if precision is not None:
            self.precision = precision
        if recall is not None:
            self.recall = recall
        if accuracy is not None:
            self.accuracy = accuracy
        if rmse is not None:
            self.rmse = rmse
        if auc is not None:
            self.auc = auc
        if mean_absolute_error is not None:
            self.mean_absolute_error = mean_absolute_error
        if mean_relative_error is not None:
            self.mean_relative_error = mean_relative_error
        if r2 is not None:
            self.r2 = r2
        if eval_id is not None:
            self.eval_id = eval_id
        if eval_version is not None:
            self.eval_version = eval_version
        if binary_threshold is not None:
            self.binary_threshold = binary_threshold
        if binary_thresholds is not None:
            self.binary_thresholds = binary_thresholds

    @property
    def evaluation(self):
        """Gets the evaluation of this EvaluationResultsEntity.  # noqa: E501


        :return: The evaluation of this EvaluationResultsEntity.  # noqa: E501
        :rtype: str
        """
        return self._evaluation

    @evaluation.setter
    def evaluation(self, evaluation):
        """Sets the evaluation of this EvaluationResultsEntity.


        :param evaluation: The evaluation of this EvaluationResultsEntity.  # noqa: E501
        :type: str
        """

        self._evaluation = evaluation

    @property
    def eval_name(self):
        """Gets the eval_name of this EvaluationResultsEntity.  # noqa: E501


        :return: The eval_name of this EvaluationResultsEntity.  # noqa: E501
        :rtype: str
        """
        return self._eval_name

    @eval_name.setter
    def eval_name(self, eval_name):
        """Sets the eval_name of this EvaluationResultsEntity.


        :param eval_name: The eval_name of this EvaluationResultsEntity.  # noqa: E501
        :type: str
        """

        self._eval_name = eval_name

    @property
    def model_instance_id(self):
        """Gets the model_instance_id of this EvaluationResultsEntity.  # noqa: E501


        :return: The model_instance_id of this EvaluationResultsEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_instance_id

    @model_instance_id.setter
    def model_instance_id(self, model_instance_id):
        """Sets the model_instance_id of this EvaluationResultsEntity.


        :param model_instance_id: The model_instance_id of this EvaluationResultsEntity.  # noqa: E501
        :type: str
        """

        self._model_instance_id = model_instance_id

    @property
    def created(self):
        """Gets the created of this EvaluationResultsEntity.  # noqa: E501

        When the evaluation result was created  # noqa: E501

        :return: The created of this EvaluationResultsEntity.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this EvaluationResultsEntity.

        When the evaluation result was created  # noqa: E501

        :param created: The created of this EvaluationResultsEntity.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def f1(self):
        """Gets the f1 of this EvaluationResultsEntity.  # noqa: E501


        :return: The f1 of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._f1

    @f1.setter
    def f1(self, f1):
        """Sets the f1 of this EvaluationResultsEntity.


        :param f1: The f1 of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._f1 = f1

    @property
    def precision(self):
        """Gets the precision of this EvaluationResultsEntity.  # noqa: E501


        :return: The precision of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """Sets the precision of this EvaluationResultsEntity.


        :param precision: The precision of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._precision = precision

    @property
    def recall(self):
        """Gets the recall of this EvaluationResultsEntity.  # noqa: E501


        :return: The recall of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._recall

    @recall.setter
    def recall(self, recall):
        """Sets the recall of this EvaluationResultsEntity.


        :param recall: The recall of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._recall = recall

    @property
    def accuracy(self):
        """Gets the accuracy of this EvaluationResultsEntity.  # noqa: E501


        :return: The accuracy of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._accuracy

    @accuracy.setter
    def accuracy(self, accuracy):
        """Sets the accuracy of this EvaluationResultsEntity.


        :param accuracy: The accuracy of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._accuracy = accuracy

    @property
    def rmse(self):
        """Gets the rmse of this EvaluationResultsEntity.  # noqa: E501


        :return: The rmse of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._rmse

    @rmse.setter
    def rmse(self, rmse):
        """Sets the rmse of this EvaluationResultsEntity.


        :param rmse: The rmse of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._rmse = rmse

    @property
    def auc(self):
        """Gets the auc of this EvaluationResultsEntity.  # noqa: E501


        :return: The auc of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._auc

    @auc.setter
    def auc(self, auc):
        """Sets the auc of this EvaluationResultsEntity.


        :param auc: The auc of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._auc = auc

    @property
    def mean_absolute_error(self):
        """Gets the mean_absolute_error of this EvaluationResultsEntity.  # noqa: E501


        :return: The mean_absolute_error of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._mean_absolute_error

    @mean_absolute_error.setter
    def mean_absolute_error(self, mean_absolute_error):
        """Sets the mean_absolute_error of this EvaluationResultsEntity.


        :param mean_absolute_error: The mean_absolute_error of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._mean_absolute_error = mean_absolute_error

    @property
    def mean_relative_error(self):
        """Gets the mean_relative_error of this EvaluationResultsEntity.  # noqa: E501


        :return: The mean_relative_error of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._mean_relative_error

    @mean_relative_error.setter
    def mean_relative_error(self, mean_relative_error):
        """Sets the mean_relative_error of this EvaluationResultsEntity.


        :param mean_relative_error: The mean_relative_error of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._mean_relative_error = mean_relative_error

    @property
    def r2(self):
        """Gets the r2 of this EvaluationResultsEntity.  # noqa: E501


        :return: The r2 of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._r2

    @r2.setter
    def r2(self, r2):
        """Sets the r2 of this EvaluationResultsEntity.


        :param r2: The r2 of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._r2 = r2

    @property
    def eval_id(self):
        """Gets the eval_id of this EvaluationResultsEntity.  # noqa: E501

        GUID of the evaluation  # noqa: E501

        :return: The eval_id of this EvaluationResultsEntity.  # noqa: E501
        :rtype: str
        """
        return self._eval_id

    @eval_id.setter
    def eval_id(self, eval_id):
        """Sets the eval_id of this EvaluationResultsEntity.

        GUID of the evaluation  # noqa: E501

        :param eval_id: The eval_id of this EvaluationResultsEntity.  # noqa: E501
        :type: str
        """

        self._eval_id = eval_id

    @property
    def eval_version(self):
        """Gets the eval_version of this EvaluationResultsEntity.  # noqa: E501


        :return: The eval_version of this EvaluationResultsEntity.  # noqa: E501
        :rtype: int
        """
        return self._eval_version

    @eval_version.setter
    def eval_version(self, eval_version):
        """Sets the eval_version of this EvaluationResultsEntity.


        :param eval_version: The eval_version of this EvaluationResultsEntity.  # noqa: E501
        :type: int
        """

        self._eval_version = eval_version

    @property
    def binary_threshold(self):
        """Gets the binary_threshold of this EvaluationResultsEntity.  # noqa: E501


        :return: The binary_threshold of this EvaluationResultsEntity.  # noqa: E501
        :rtype: float
        """
        return self._binary_threshold

    @binary_threshold.setter
    def binary_threshold(self, binary_threshold):
        """Sets the binary_threshold of this EvaluationResultsEntity.


        :param binary_threshold: The binary_threshold of this EvaluationResultsEntity.  # noqa: E501
        :type: float
        """

        self._binary_threshold = binary_threshold

    @property
    def binary_thresholds(self):
        """Gets the binary_thresholds of this EvaluationResultsEntity.  # noqa: E501


        :return: The binary_thresholds of this EvaluationResultsEntity.  # noqa: E501
        :rtype: str
        """
        return self._binary_thresholds

    @binary_thresholds.setter
    def binary_thresholds(self, binary_thresholds):
        """Sets the binary_thresholds of this EvaluationResultsEntity.


        :param binary_thresholds: The binary_thresholds of this EvaluationResultsEntity.  # noqa: E501
        :type: str
        """

        self._binary_thresholds = binary_thresholds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EvaluationResultsEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MultiClassClassificationResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ranked_outcomes': 'list[list[str]]',
        'max_outcomes': 'list[str]',
        'probabilities': 'list[list[float]]'
    }

    attribute_map = {
        'ranked_outcomes': 'rankedOutcomes',
        'max_outcomes': 'maxOutcomes',
        'probabilities': 'probabilities'
    }

    def __init__(self, ranked_outcomes=None, max_outcomes=None, probabilities=None):  # noqa: E501
        """MultiClassClassificationResult - a model defined in Swagger"""  # noqa: E501

        self._ranked_outcomes = None
        self._max_outcomes = None
        self._probabilities = None
        self.discriminator = None

        if ranked_outcomes is not None:
            self.ranked_outcomes = ranked_outcomes
        if max_outcomes is not None:
            self.max_outcomes = max_outcomes
        if probabilities is not None:
            self.probabilities = probabilities

    @property
    def ranked_outcomes(self):
        """Gets the ranked_outcomes of this MultiClassClassificationResult.  # noqa: E501


        :return: The ranked_outcomes of this MultiClassClassificationResult.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._ranked_outcomes

    @ranked_outcomes.setter
    def ranked_outcomes(self, ranked_outcomes):
        """Sets the ranked_outcomes of this MultiClassClassificationResult.


        :param ranked_outcomes: The ranked_outcomes of this MultiClassClassificationResult.  # noqa: E501
        :type: list[list[str]]
        """

        self._ranked_outcomes = ranked_outcomes

    @property
    def max_outcomes(self):
        """Gets the max_outcomes of this MultiClassClassificationResult.  # noqa: E501


        :return: The max_outcomes of this MultiClassClassificationResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._max_outcomes

    @max_outcomes.setter
    def max_outcomes(self, max_outcomes):
        """Sets the max_outcomes of this MultiClassClassificationResult.


        :param max_outcomes: The max_outcomes of this MultiClassClassificationResult.  # noqa: E501
        :type: list[str]
        """

        self._max_outcomes = max_outcomes

    @property
    def probabilities(self):
        """Gets the probabilities of this MultiClassClassificationResult.  # noqa: E501


        :return: The probabilities of this MultiClassClassificationResult.  # noqa: E501
        :rtype: list[list[float]]
        """
        return self._probabilities

    @probabilities.setter
    def probabilities(self, probabilities):
        """Sets the probabilities of this MultiClassClassificationResult.


        :param probabilities: The probabilities of this MultiClassClassificationResult.  # noqa: E501
        :type: list[list[float]]
        """

        self._probabilities = probabilities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultiClassClassificationResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CreateJobRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compute_resource_id': 'int',
        'storage_resource_id': 'int',
        'job_args': 'str',
        'output_file_name': 'str'
    }

    attribute_map = {
        'compute_resource_id': 'computeResourceId',
        'storage_resource_id': 'storageResourceId',
        'job_args': 'jobArgs',
        'output_file_name': 'outputFileName'
    }

    def __init__(self, compute_resource_id=None, storage_resource_id=None, job_args=None, output_file_name=None):  # noqa: E501
        """CreateJobRequest - a model defined in Swagger"""  # noqa: E501

        self._compute_resource_id = None
        self._storage_resource_id = None
        self._job_args = None
        self._output_file_name = None
        self.discriminator = None

        if compute_resource_id is not None:
            self.compute_resource_id = compute_resource_id
        if storage_resource_id is not None:
            self.storage_resource_id = storage_resource_id
        if job_args is not None:
            self.job_args = job_args
        if output_file_name is not None:
            self.output_file_name = output_file_name

    @property
    def compute_resource_id(self):
        """Gets the compute_resource_id of this CreateJobRequest.  # noqa: E501

        Compute resource ID  # noqa: E501

        :return: The compute_resource_id of this CreateJobRequest.  # noqa: E501
        :rtype: int
        """
        return self._compute_resource_id

    @compute_resource_id.setter
    def compute_resource_id(self, compute_resource_id):
        """Sets the compute_resource_id of this CreateJobRequest.

        Compute resource ID  # noqa: E501

        :param compute_resource_id: The compute_resource_id of this CreateJobRequest.  # noqa: E501
        :type: int
        """

        self._compute_resource_id = compute_resource_id

    @property
    def storage_resource_id(self):
        """Gets the storage_resource_id of this CreateJobRequest.  # noqa: E501

        Storage resource ID  # noqa: E501

        :return: The storage_resource_id of this CreateJobRequest.  # noqa: E501
        :rtype: int
        """
        return self._storage_resource_id

    @storage_resource_id.setter
    def storage_resource_id(self, storage_resource_id):
        """Sets the storage_resource_id of this CreateJobRequest.

        Storage resource ID  # noqa: E501

        :param storage_resource_id: The storage_resource_id of this CreateJobRequest.  # noqa: E501
        :type: int
        """

        self._storage_resource_id = storage_resource_id

    @property
    def job_args(self):
        """Gets the job_args of this CreateJobRequest.  # noqa: E501

        Job arguments  # noqa: E501

        :return: The job_args of this CreateJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._job_args

    @job_args.setter
    def job_args(self, job_args):
        """Sets the job_args of this CreateJobRequest.

        Job arguments  # noqa: E501

        :param job_args: The job_args of this CreateJobRequest.  # noqa: E501
        :type: str
        """

        self._job_args = job_args

    @property
    def output_file_name(self):
        """Gets the output_file_name of this CreateJobRequest.  # noqa: E501

        Output file name  # noqa: E501

        :return: The output_file_name of this CreateJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._output_file_name

    @output_file_name.setter
    def output_file_name(self, output_file_name):
        """Sets the output_file_name of this CreateJobRequest.

        Output file name  # noqa: E501

        :param output_file_name: The output_file_name of this CreateJobRequest.  # noqa: E501
        :type: str
        """

        self._output_file_name = output_file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MinibatchEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mini_batch_id': 'str',
        'eval_id': 'str',
        'eval_version': 'int',
        'batch_version': 'int'
    }

    attribute_map = {
        'mini_batch_id': 'miniBatchId',
        'eval_id': 'evalId',
        'eval_version': 'evalVersion',
        'batch_version': 'batchVersion'
    }

    def __init__(self, mini_batch_id=None, eval_id=None, eval_version=None, batch_version=None):  # noqa: E501
        """MinibatchEntity - a model defined in Swagger"""  # noqa: E501

        self._mini_batch_id = None
        self._eval_id = None
        self._eval_version = None
        self._batch_version = None
        self.discriminator = None

        if mini_batch_id is not None:
            self.mini_batch_id = mini_batch_id
        if eval_id is not None:
            self.eval_id = eval_id
        if eval_version is not None:
            self.eval_version = eval_version
        if batch_version is not None:
            self.batch_version = batch_version

    @property
    def mini_batch_id(self):
        """Gets the mini_batch_id of this MinibatchEntity.  # noqa: E501

        GUID of mini batch  # noqa: E501

        :return: The mini_batch_id of this MinibatchEntity.  # noqa: E501
        :rtype: str
        """
        return self._mini_batch_id

    @mini_batch_id.setter
    def mini_batch_id(self, mini_batch_id):
        """Sets the mini_batch_id of this MinibatchEntity.

        GUID of mini batch  # noqa: E501

        :param mini_batch_id: The mini_batch_id of this MinibatchEntity.  # noqa: E501
        :type: str
        """

        self._mini_batch_id = mini_batch_id

    @property
    def eval_id(self):
        """Gets the eval_id of this MinibatchEntity.  # noqa: E501

        GUID of the evaluation  # noqa: E501

        :return: The eval_id of this MinibatchEntity.  # noqa: E501
        :rtype: str
        """
        return self._eval_id

    @eval_id.setter
    def eval_id(self, eval_id):
        """Sets the eval_id of this MinibatchEntity.

        GUID of the evaluation  # noqa: E501

        :param eval_id: The eval_id of this MinibatchEntity.  # noqa: E501
        :type: str
        """

        self._eval_id = eval_id

    @property
    def eval_version(self):
        """Gets the eval_version of this MinibatchEntity.  # noqa: E501

        Eval version  # noqa: E501

        :return: The eval_version of this MinibatchEntity.  # noqa: E501
        :rtype: int
        """
        return self._eval_version

    @eval_version.setter
    def eval_version(self, eval_version):
        """Sets the eval_version of this MinibatchEntity.

        Eval version  # noqa: E501

        :param eval_version: The eval_version of this MinibatchEntity.  # noqa: E501
        :type: int
        """

        self._eval_version = eval_version

    @property
    def batch_version(self):
        """Gets the batch_version of this MinibatchEntity.  # noqa: E501

        Batch version  # noqa: E501

        :return: The batch_version of this MinibatchEntity.  # noqa: E501
        :rtype: int
        """
        return self._batch_version

    @batch_version.setter
    def batch_version(self, batch_version):
        """Sets the batch_version of this MinibatchEntity.

        Batch version  # noqa: E501

        :param batch_version: The batch_version of this MinibatchEntity.  # noqa: E501
        :type: int
        """

        self._batch_version = batch_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MinibatchEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DetectedObject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'center_x': 'float',
        'center_y': 'float',
        'width': 'float',
        'height': 'float',
        'predicted_classes': 'list[str]',
        'confidences': 'list[float]'
    }

    attribute_map = {
        'center_x': 'centerX',
        'center_y': 'centerY',
        'width': 'width',
        'height': 'height',
        'predicted_classes': 'predictedClasses',
        'confidences': 'confidences'
    }

    def __init__(self, center_x=None, center_y=None, width=None, height=None, predicted_classes=None, confidences=None):  # noqa: E501
        """DetectedObject - a model defined in Swagger"""  # noqa: E501

        self._center_x = None
        self._center_y = None
        self._width = None
        self._height = None
        self._predicted_classes = None
        self._confidences = None
        self.discriminator = None

        if center_x is not None:
            self.center_x = center_x
        if center_y is not None:
            self.center_y = center_y
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if predicted_classes is not None:
            self.predicted_classes = predicted_classes
        if confidences is not None:
            self.confidences = confidences

    @property
    def center_x(self):
        """Gets the center_x of this DetectedObject.  # noqa: E501


        :return: The center_x of this DetectedObject.  # noqa: E501
        :rtype: float
        """
        return self._center_x

    @center_x.setter
    def center_x(self, center_x):
        """Sets the center_x of this DetectedObject.


        :param center_x: The center_x of this DetectedObject.  # noqa: E501
        :type: float
        """

        self._center_x = center_x

    @property
    def center_y(self):
        """Gets the center_y of this DetectedObject.  # noqa: E501


        :return: The center_y of this DetectedObject.  # noqa: E501
        :rtype: float
        """
        return self._center_y

    @center_y.setter
    def center_y(self, center_y):
        """Sets the center_y of this DetectedObject.


        :param center_y: The center_y of this DetectedObject.  # noqa: E501
        :type: float
        """

        self._center_y = center_y

    @property
    def width(self):
        """Gets the width of this DetectedObject.  # noqa: E501


        :return: The width of this DetectedObject.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DetectedObject.


        :param width: The width of this DetectedObject.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this DetectedObject.  # noqa: E501


        :return: The height of this DetectedObject.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this DetectedObject.


        :param height: The height of this DetectedObject.  # noqa: E501
        :type: float
        """

        self._height = height

    @property
    def predicted_classes(self):
        """Gets the predicted_classes of this DetectedObject.  # noqa: E501


        :return: The predicted_classes of this DetectedObject.  # noqa: E501
        :rtype: list[str]
        """
        return self._predicted_classes

    @predicted_classes.setter
    def predicted_classes(self, predicted_classes):
        """Sets the predicted_classes of this DetectedObject.


        :param predicted_classes: The predicted_classes of this DetectedObject.  # noqa: E501
        :type: list[str]
        """

        self._predicted_classes = predicted_classes

    @property
    def confidences(self):
        """Gets the confidences of this DetectedObject.  # noqa: E501


        :return: The confidences of this DetectedObject.  # noqa: E501
        :rtype: list[float]
        """
        return self._confidences

    @confidences.setter
    def confidences(self, confidences):
        """Sets the confidences of this DetectedObject.


        :param confidences: The confidences of this DetectedObject.  # noqa: E501
        :type: list[float]
        """

        self._confidences = confidences

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectedObject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import skil_client
from skil_client.api.default_api import DefaultApi  # noqa: E501
from skil_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = skil_client.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accumulated_results(self):
        """Test case for accumulated_results

        Tells how many retraining examples have labels associated with them.  # noqa: E501
        """
        pass

    def test_add_credentials(self):
        """Test case for add_credentials

        Adds credentials  # noqa: E501
        """
        pass

    def test_add_evaluation_result(self):
        """Test case for add_evaluation_result

        Adds an evaluation result  # noqa: E501
        """
        pass

    def test_add_example_for_batch(self):
        """Test case for add_example_for_batch

        Adds a number of examples to a minibatch ID given an AddExampleRequest.  # noqa: E501
        """
        pass

    def test_add_example_to_minibatch(self):
        """Test case for add_example_to_minibatch

        Adds an example to a minibatch  # noqa: E501
        """
        pass

    def test_add_experiment(self):
        """Test case for add_experiment

        Add an experiment, given an experiment entity  # noqa: E501
        """
        pass

    def test_add_feedback_binary(self):
        """Test case for add_feedback_binary

        """
        pass

    def test_add_feedback_json(self):
        """Test case for add_feedback_json

        Gets the retraining feedback for the given batch ID.  # noqa: E501
        """
        pass

    def test_add_minibatch(self):
        """Test case for add_minibatch

        Adds a minibatch  # noqa: E501
        """
        pass

    def test_add_model_feedback(self):
        """Test case for add_model_feedback

        Adds an evaluation feedback to the model against a given minibatch id.  # noqa: E501
        """
        pass

    def test_add_model_history(self):
        """Test case for add_model_history

        Add a model history / workspace  # noqa: E501
        """
        pass

    def test_add_model_instance(self):
        """Test case for add_model_instance

        Adds a model  # noqa: E501
        """
        pass

    def test_add_resource(self):
        """Test case for add_resource

        Adds a resource  # noqa: E501
        """
        pass

    def test_add_resource_group(self):
        """Test case for add_resource_group

        Adds a resource group  # noqa: E501
        """
        pass

    def test_add_resource_to_group(self):
        """Test case for add_resource_to_group

        Adds a resource to a resource group  # noqa: E501
        """
        pass

    def test_aggregate_model_results(self):
        """Test case for aggregate_model_results

        Aggregates the evaluaition results of a model instance, based on the evaluation type  # noqa: E501
        """
        pass

    def test_change_user_password(self):
        """Test case for change_user_password

        Change user's password  # noqa: E501
        """
        pass

    def test_classify(self):
        """Test case for classify

        Use the deployed model to classify the input  # noqa: E501
        """
        pass

    def test_classifyarray(self):
        """Test case for classifyarray

        Same as /classify but returns the output as Base64NDArrayBody  # noqa: E501
        """
        pass

    def test_classifyimage(self):
        """Test case for classifyimage

        Use the deployed model to classify the input, using input image file from multipart form data.  # noqa: E501
        """
        pass

    def test_clear_state(self):
        """Test case for clear_state

        Clears the accumulated data for retraining.  # noqa: E501
        """
        pass

    def test_create_job(self):
        """Test case for create_job

        Create a job  # noqa: E501
        """
        pass

    def test_create_model_history(self):
        """Test case for create_model_history

        Creates model History  # noqa: E501
        """
        pass

    def test_delete_credentials_by_id(self):
        """Test case for delete_credentials_by_id

        Delete credentials given an ID  # noqa: E501
        """
        pass

    def test_delete_experiment(self):
        """Test case for delete_experiment

        Deletes an experiment, given an experiment entity  # noqa: E501
        """
        pass

    def test_delete_job_by_id(self):
        """Test case for delete_job_by_id

        Deletes a job given its ID  # noqa: E501
        """
        pass

    def test_delete_model(self):
        """Test case for delete_model

        Delete a model by deployment and model id  # noqa: E501
        """
        pass

    def test_delete_model_history(self):
        """Test case for delete_model_history

        Deletes a model history / workspace, given its ID  # noqa: E501
        """
        pass

    def test_delete_model_instance(self):
        """Test case for delete_model_instance

        Deletes a model instance, given its ID  # noqa: E501
        """
        pass

    def test_delete_resource_by_id(self):
        """Test case for delete_resource_by_id

        Delete the resource with the specified resource ID  # noqa: E501
        """
        pass

    def test_delete_resource_from_group(self):
        """Test case for delete_resource_from_group

        Removes a resource from a resource group  # noqa: E501
        """
        pass

    def test_delete_resource_group_by_id(self):
        """Test case for delete_resource_group_by_id

        Delete the resource group with the specified resource group ID  # noqa: E501
        """
        pass

    def test_deploy_model(self):
        """Test case for deploy_model

        Deploy a model in a deployment group.  # noqa: E501
        """
        pass

    def test_deployment_create(self):
        """Test case for deployment_create

        Create a new deployment group.  # noqa: E501
        """
        pass

    def test_deployment_delete(self):
        """Test case for deployment_delete

        Delete a deployment by id  # noqa: E501
        """
        pass

    def test_deployment_get(self):
        """Test case for deployment_get

        Get a deployment details by id  # noqa: E501
        """
        pass

    def test_deployments(self):
        """Test case for deployments

        Get a list of deployments  # noqa: E501
        """
        pass

    def test_detectobjects(self):
        """Test case for detectobjects

        Detect the objects, given a (input) prediction request  # noqa: E501
        """
        pass

    def test_download_job_output_file(self):
        """Test case for download_job_output_file

        Download the output file from the job's execution. This will ONLY work if the job's run status is 'COMPLETE'.  # noqa: E501
        """
        pass

    def test_generate_auth_token(self):
        """Test case for generate_auth_token

        Generate new auth token  # noqa: E501
        """
        pass

    def test_get_all_jobs(self):
        """Test case for get_all_jobs

        Get a list of all available jobs  # noqa: E501
        """
        pass

    def test_get_array(self):
        """Test case for get_array

        Get the memory mapped array based on the array type.  # noqa: E501
        """
        pass

    def test_get_array_indices(self):
        """Test case for get_array_indices

        Get the memory mapped array indices based on the array type.  # noqa: E501
        """
        pass

    def test_get_array_range(self):
        """Test case for get_array_range

        Get the memory mapped array within a range based on the array type.  # noqa: E501
        """
        pass

    def test_get_auth_policy(self):
        """Test case for get_auth_policy

        Get auth policy  # noqa: E501
        """
        pass

    def test_get_best_model_among_model_ids(self):
        """Test case for get_best_model_among_model_ids

        Gets the best model among the given model instance IDs, based on the evaluation type and column metric  # noqa: E501
        """
        pass

    def test_get_credentials_by_id(self):
        """Test case for get_credentials_by_id

        Get credentials given an ID  # noqa: E501
        """
        pass

    def test_get_current_model(self):
        """Test case for get_current_model

        Returns the current model being used for retraining.  # noqa: E501
        """
        pass

    def test_get_evaluation_for_model_id(self):
        """Test case for get_evaluation_for_model_id

        Gets the list of evaluation results entity, given a model instance ID  # noqa: E501
        """
        pass

    def test_get_examples_for_minibatch(self):
        """Test case for get_examples_for_minibatch

        Gets all the examples for a minibatch ID  # noqa: E501
        """
        pass

    def test_get_experiment(self):
        """Test case for get_experiment

        Obtain an experiment's details, given its ID  # noqa: E501
        """
        pass

    def test_get_experiments_for_model_history(self):
        """Test case for get_experiments_for_model_history

        Obtain all experiments for a model history / workspace  # noqa: E501
        """
        pass

    def test_get_job_by_id(self):
        """Test case for get_job_by_id

        Get a job by its ID  # noqa: E501
        """
        pass

    def test_get_last_evaluation(self):
        """Test case for get_last_evaluation

        Get the last evaluation specifications from the current model.  # noqa: E501
        """
        pass

    def test_get_minibatch(self):
        """Test case for get_minibatch

        Gets a minibatch for the model  # noqa: E501
        """
        pass

    def test_get_model_history(self):
        """Test case for get_model_history

        Gets a model history, given its ID  # noqa: E501
        """
        pass

    def test_get_model_instance(self):
        """Test case for get_model_instance

        Gets a model instance, given its ID  # noqa: E501
        """
        pass

    def test_get_models_for_experiment(self):
        """Test case for get_models_for_experiment

        Obtain a list of all the models for an experiment  # noqa: E501
        """
        pass

    def test_get_resource_by_id(self):
        """Test case for get_resource_by_id

        Get the resource with the specified resource ID  # noqa: E501
        """
        pass

    def test_get_resource_by_sub_type(self):
        """Test case for get_resource_by_sub_type

        Get all the resources with the specified resource subtype  # noqa: E501
        """
        pass

    def test_get_resource_by_type(self):
        """Test case for get_resource_by_type

        Get all the resources with the specified resource type  # noqa: E501
        """
        pass

    def test_get_resource_details_by_id(self):
        """Test case for get_resource_details_by_id

        Get the resource details with the specified resource ID  # noqa: E501
        """
        pass

    def test_get_resource_group_by_id(self):
        """Test case for get_resource_group_by_id

        Get the resource group with the specified resource group ID  # noqa: E501
        """
        pass

    def test_get_resource_groups(self):
        """Test case for get_resource_groups

        Get a list of all the resource groups  # noqa: E501
        """
        pass

    def test_get_resources(self):
        """Test case for get_resources

        A list of all known/registered resources, of all types  # noqa: E501
        """
        pass

    def test_get_resources_from_group(self):
        """Test case for get_resources_from_group

        Get all resources from a resource group  # noqa: E501
        """
        pass

    def test_get_roles(self):
        """Test case for get_roles

        Get all roles.  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get a user by user ID  # noqa: E501
        """
        pass

    def test_get_user_auth_tokens(self):
        """Test case for get_user_auth_tokens

        Get auth tokens for a user.  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Get all users.  # noqa: E501
        """
        pass

    def test_is_training(self):
        """Test case for is_training

        Get the retraining status  # noqa: E501
        """
        pass

    def test_jsonarray(self):
        """Test case for jsonarray

        Run inference on the input and returns it as a JsonArrayResponse  # noqa: E501
        """
        pass

    def test_knn(self):
        """Test case for knn

        Runs knn on the given index with the given k  # noqa: E501
        """
        pass

    def test_knnnew(self):
        """Test case for knnnew

        Run a k nearest neighbors search on a NEW data point  # noqa: E501
        """
        pass

    def test_list_all_experiments(self):
        """Test case for list_all_experiments

        List all of the experiments in every model history / workspace  # noqa: E501
        """
        pass

    def test_logfilepath(self):
        """Test case for logfilepath

        Get logs file path  # noqa: E501
        """
        pass

    def test_login(self):
        """Test case for login

        Post JSON credentials and obtain a JWT authorization token.  # noqa: E501
        """
        pass

    def test_logs(self):
        """Test case for logs

        Get logs  # noqa: E501
        """
        pass

    def test_meta_get(self):
        """Test case for meta_get

        this method can be used to get the meta data for the current model which set to the server  # noqa: E501
        """
        pass

    def test_meta_post(self):
        """Test case for meta_post

        This method can be used to set meta data for the current model which is set to the server  # noqa: E501
        """
        pass

    def test_model_state_change(self):
        """Test case for model_state_change

        Modify the state (start/stop) of a deployed model  # noqa: E501
        """
        pass

    def test_models(self):
        """Test case for models

        Retrieve a list of all the deployed models given a deployment id  # noqa: E501
        """
        pass

    def test_modelset(self):
        """Test case for modelset

        Set the model to be served  # noqa: E501
        """
        pass

    def test_modelupdate(self):
        """Test case for modelupdate

        Update the model to be served  # noqa: E501
        """
        pass

    def test_multiclassify(self):
        """Test case for multiclassify

        Represents all of the labels for a given classification  # noqa: E501
        """
        pass

    def test_multipredict(self):
        """Test case for multipredict

        Get the output from the network, based on the given INDArray[] input  # noqa: E501
        """
        pass

    def test_multipredictimage(self):
        """Test case for multipredictimage

        Get the output from the network using the given image file using the /multipredict endpoint's method  # noqa: E501
        """
        pass

    def test_num_revisions(self):
        """Test case for num_revisions

        Gets the number of retrained models written with retraining.  # noqa: E501
        """
        pass

    def test_predict(self):
        """Test case for predict

        Run inference on the input array.  # noqa: E501
        """
        pass

    def test_predict_error(self):
        """Test case for predict_error

        Runs inference and find invalid rows based on the input data. Output is defined relative to the output adapter specified.  # noqa: E501
        """
        pass

    def test_predict_v2_file(self):
        """Test case for predict_v2_file

        Runs inference based on the input data. Output is defined relative to the output adapter specified.  # noqa: E501
        """
        pass

    def test_predict_v2_json(self):
        """Test case for predict_v2_json

        Runs inference based on the input data. Output is defined relative to the output adapter specified.  # noqa: E501
        """
        pass

    def test_predictimage(self):
        """Test case for predictimage

        Run inference on the input array, using input image file from multipart form data.  # noqa: E501
        """
        pass

    def test_predictwithpreprocess(self):
        """Test case for predictwithpreprocess

        Preprocesses the input and run inference on it  # noqa: E501
        """
        pass

    def test_predictwithpreprocessjson(self):
        """Test case for predictwithpreprocessjson

        Preprocesses the input and run inference on it and returns it as a JsonArrayResponse  # noqa: E501
        """
        pass

    def test_raw_predict_binary(self):
        """Test case for raw_predict_binary

        Runs inference based on the input data. Output is defined relative to the output adapter specified.  # noqa: E501
        """
        pass

    def test_refresh_job_status(self):
        """Test case for refresh_job_status

        Refresh the remote job status. Can be used for monitoring.  # noqa: E501
        """
        pass

    def test_register_user(self):
        """Test case for register_user

        Register a new user  # noqa: E501
        """
        pass

    def test_reimport_model(self):
        """Test case for reimport_model

        Reimport a model to a previous deployed model in a deployment  # noqa: E501
        """
        pass

    def test_revoke_user_token(self):
        """Test case for revoke_user_token

        Revoke a user token.  # noqa: E501
        """
        pass

    def test_rollback(self):
        """Test case for rollback

        Rollback to a previous revision of the model.  # noqa: E501
        """
        pass

    def test_run_a_job(self):
        """Test case for run_a_job

        Start running an (already created) job on the remote resource  # noqa: E501
        """
        pass

    def test_transform_csv(self):
        """Test case for transform_csv

        Takes a BatchCSVRecord and returns the transformed array as BatchCSVRecord  # noqa: E501
        """
        pass

    def test_transformarray(self):
        """Test case for transformarray

        Takes a batch input arrays and transforms it  # noqa: E501
        """
        pass

    def test_transformimage(self):
        """Test case for transformimage

        Takes multiple multipart image file to transform and returns Base64NDArrayBody  # noqa: E501
        """
        pass

    def test_transformincremental_csv(self):
        """Test case for transformincremental_csv

        Takes SingleCSVRecord as input and returns the transformed array as SingleCSVRecord  # noqa: E501
        """
        pass

    def test_transformincrementalarray(self):
        """Test case for transformincrementalarray

        Same as /transformincremental but returns Base64NDArrayBody.  # noqa: E501
        """
        pass

    def test_transformincrementalimage(self):
        """Test case for transformincrementalimage

        Takes a single multipart image file to transform and returns Base64NDArrayBody  # noqa: E501
        """
        pass

    def test_transformprocess_get(self):
        """Test case for transformprocess_get

        Gets the JSON string of the deployed transform process (CSV or Image)  # noqa: E501
        """
        pass

    def test_transformprocess_post(self):
        """Test case for transformprocess_post

        Sets the deployed (CSV or Image) transform process through the provided JSON string  # noqa: E501
        """
        pass

    def test_update_auth_policy(self):
        """Test case for update_auth_policy

        Update auth policy  # noqa: E501
        """
        pass

    def test_update_best_model_for_experiment(self):
        """Test case for update_best_model_for_experiment

        Updates the best model for an experiment  # noqa: E501
        """
        pass

    def test_update_experiment(self):
        """Test case for update_experiment

        Updates an experiment, given an experiment entity  # noqa: E501
        """
        pass

    def test_update_model_history(self):
        """Test case for update_model_history

        Update a model history / workspace  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update a user  # noqa: E501
        """
        pass

    def test_upload(self):
        """Test case for upload

        Upload a model file to SKIL for import.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ImportModelRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'scale': 'int',
        'uri': 'list[str]',
        'model_type': 'str',
        'file_location': 'str',
        'jvm_args': 'str',
        'sub_type': 'str',
        'labels_file_location': 'str',
        'extra_args': 'str',
        'etl_json': 'str',
        'input_names': 'list[str]',
        'output_names': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'scale': 'scale',
        'uri': 'uri',
        'model_type': 'modelType',
        'file_location': 'fileLocation',
        'jvm_args': 'jvmArgs',
        'sub_type': 'subType',
        'labels_file_location': 'labelsFileLocation',
        'extra_args': 'extraArgs',
        'etl_json': 'etlJson',
        'input_names': 'inputNames',
        'output_names': 'outputNames'
    }

    def __init__(self, name=None, scale=None, uri=None, model_type=None, file_location=None, jvm_args=None, sub_type=None, labels_file_location=None, extra_args=None, etl_json=None, input_names=None, output_names=None):  # noqa: E501
        """ImportModelRequest - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._scale = None
        self._uri = None
        self._model_type = None
        self._file_location = None
        self._jvm_args = None
        self._sub_type = None
        self._labels_file_location = None
        self._extra_args = None
        self._etl_json = None
        self._input_names = None
        self._output_names = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if scale is not None:
            self.scale = scale
        if uri is not None:
            self.uri = uri
        if model_type is not None:
            self.model_type = model_type
        if file_location is not None:
            self.file_location = file_location
        if jvm_args is not None:
            self.jvm_args = jvm_args
        if sub_type is not None:
            self.sub_type = sub_type
        if labels_file_location is not None:
            self.labels_file_location = labels_file_location
        if extra_args is not None:
            self.extra_args = extra_args
        if etl_json is not None:
            self.etl_json = etl_json
        if input_names is not None:
            self.input_names = input_names
        if output_names is not None:
            self.output_names = output_names

    @property
    def name(self):
        """Gets the name of this ImportModelRequest.  # noqa: E501


        :return: The name of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ImportModelRequest.


        :param name: The name of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def scale(self):
        """Gets the scale of this ImportModelRequest.  # noqa: E501


        :return: The scale of this ImportModelRequest.  # noqa: E501
        :rtype: int
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """Sets the scale of this ImportModelRequest.


        :param scale: The scale of this ImportModelRequest.  # noqa: E501
        :type: int
        """

        self._scale = scale

    @property
    def uri(self):
        """Gets the uri of this ImportModelRequest.  # noqa: E501


        :return: The uri of this ImportModelRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ImportModelRequest.


        :param uri: The uri of this ImportModelRequest.  # noqa: E501
        :type: list[str]
        """

        self._uri = uri

    @property
    def model_type(self):
        """Gets the model_type of this ImportModelRequest.  # noqa: E501


        :return: The model_type of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this ImportModelRequest.


        :param model_type: The model_type of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    @property
    def file_location(self):
        """Gets the file_location of this ImportModelRequest.  # noqa: E501


        :return: The file_location of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._file_location

    @file_location.setter
    def file_location(self, file_location):
        """Sets the file_location of this ImportModelRequest.


        :param file_location: The file_location of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._file_location = file_location

    @property
    def jvm_args(self):
        """Gets the jvm_args of this ImportModelRequest.  # noqa: E501


        :return: The jvm_args of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._jvm_args

    @jvm_args.setter
    def jvm_args(self, jvm_args):
        """Sets the jvm_args of this ImportModelRequest.


        :param jvm_args: The jvm_args of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._jvm_args = jvm_args

    @property
    def sub_type(self):
        """Gets the sub_type of this ImportModelRequest.  # noqa: E501


        :return: The sub_type of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this ImportModelRequest.


        :param sub_type: The sub_type of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._sub_type = sub_type

    @property
    def labels_file_location(self):
        """Gets the labels_file_location of this ImportModelRequest.  # noqa: E501


        :return: The labels_file_location of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._labels_file_location

    @labels_file_location.setter
    def labels_file_location(self, labels_file_location):
        """Sets the labels_file_location of this ImportModelRequest.


        :param labels_file_location: The labels_file_location of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._labels_file_location = labels_file_location

    @property
    def extra_args(self):
        """Gets the extra_args of this ImportModelRequest.  # noqa: E501


        :return: The extra_args of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._extra_args

    @extra_args.setter
    def extra_args(self, extra_args):
        """Sets the extra_args of this ImportModelRequest.


        :param extra_args: The extra_args of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._extra_args = extra_args

    @property
    def etl_json(self):
        """Gets the etl_json of this ImportModelRequest.  # noqa: E501


        :return: The etl_json of this ImportModelRequest.  # noqa: E501
        :rtype: str
        """
        return self._etl_json

    @etl_json.setter
    def etl_json(self, etl_json):
        """Sets the etl_json of this ImportModelRequest.


        :param etl_json: The etl_json of this ImportModelRequest.  # noqa: E501
        :type: str
        """

        self._etl_json = etl_json

    @property
    def input_names(self):
        """Gets the input_names of this ImportModelRequest.  # noqa: E501


        :return: The input_names of this ImportModelRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._input_names

    @input_names.setter
    def input_names(self, input_names):
        """Sets the input_names of this ImportModelRequest.


        :param input_names: The input_names of this ImportModelRequest.  # noqa: E501
        :type: list[str]
        """

        self._input_names = input_names

    @property
    def output_names(self):
        """Gets the output_names of this ImportModelRequest.  # noqa: E501


        :return: The output_names of this ImportModelRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._output_names

    @output_names.setter
    def output_names(self, output_names):
        """Sets the output_names of this ImportModelRequest.


        :param output_names: The output_names of this ImportModelRequest.  # noqa: E501
        :type: list[str]
        """

        self._output_names = output_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportModelRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BestModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ids': 'list[str]',
        'column_name_metric': 'str',
        'eval_type': 'str'
    }

    attribute_map = {
        'ids': 'ids',
        'column_name_metric': 'columnNameMetric',
        'eval_type': 'evalType'
    }

    def __init__(self, ids=None, column_name_metric=None, eval_type=None):  # noqa: E501
        """BestModel - a model defined in Swagger"""  # noqa: E501

        self._ids = None
        self._column_name_metric = None
        self._eval_type = None
        self.discriminator = None

        if ids is not None:
            self.ids = ids
        if column_name_metric is not None:
            self.column_name_metric = column_name_metric
        if eval_type is not None:
            self.eval_type = eval_type

    @property
    def ids(self):
        """Gets the ids of this BestModel.  # noqa: E501

        the list of GUIDs for the models to get the best model from  # noqa: E501

        :return: The ids of this BestModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this BestModel.

        the list of GUIDs for the models to get the best model from  # noqa: E501

        :param ids: The ids of this BestModel.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    @property
    def column_name_metric(self):
        """Gets the column_name_metric of this BestModel.  # noqa: E501

        Name of the column metric (in an evaluation result) to get the best model from.  # noqa: E501

        :return: The column_name_metric of this BestModel.  # noqa: E501
        :rtype: str
        """
        return self._column_name_metric

    @column_name_metric.setter
    def column_name_metric(self, column_name_metric):
        """Sets the column_name_metric of this BestModel.

        Name of the column metric (in an evaluation result) to get the best model from.  # noqa: E501

        :param column_name_metric: The column_name_metric of this BestModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["f1", "precision", "recall", "accuracy", "rmse", "auc", "meanAbsoluteError", "meanRelativeError", "r2"]  # noqa: E501
        if column_name_metric not in allowed_values:
            raise ValueError(
                "Invalid value for `column_name_metric` ({0}), must be one of {1}"  # noqa: E501
                .format(column_name_metric, allowed_values)
            )

        self._column_name_metric = column_name_metric

    @property
    def eval_type(self):
        """Gets the eval_type of this BestModel.  # noqa: E501

        the evaluation type to aggregate for each model's revisions  # noqa: E501

        :return: The eval_type of this BestModel.  # noqa: E501
        :rtype: str
        """
        return self._eval_type

    @eval_type.setter
    def eval_type(self, eval_type):
        """Sets the eval_type of this BestModel.

        the evaluation type to aggregate for each model's revisions  # noqa: E501

        :param eval_type: The eval_type of this BestModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["ROC_BINARY", "ROC", "EVALUATION_BINARY", "EVALUATION", "REGRESSON_EVALUATION", "ROC_MULTI_CLASS"]  # noqa: E501
        if eval_type not in allowed_values:
            raise ValueError(
                "Invalid value for `eval_type` ({0}), must be one of {1}"  # noqa: E501
                .format(eval_type, allowed_values)
            )

        self._eval_type = eval_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BestModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Base64NDArrayBodyKNN(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ndarray': 'str',
        'k': 'int',
        'force_fill_k': 'bool'
    }

    attribute_map = {
        'ndarray': 'ndarray',
        'k': 'k',
        'force_fill_k': 'forceFillK'
    }

    def __init__(self, ndarray=None, k=None, force_fill_k=None):  # noqa: E501
        """Base64NDArrayBodyKNN - a model defined in Swagger"""  # noqa: E501

        self._ndarray = None
        self._k = None
        self._force_fill_k = None
        self.discriminator = None

        if ndarray is not None:
            self.ndarray = ndarray
        if k is not None:
            self.k = k
        if force_fill_k is not None:
            self.force_fill_k = force_fill_k

    @property
    def ndarray(self):
        """Gets the ndarray of this Base64NDArrayBodyKNN.  # noqa: E501

        the array to run the search on. Note that this must be a row vector  # noqa: E501

        :return: The ndarray of this Base64NDArrayBodyKNN.  # noqa: E501
        :rtype: str
        """
        return self._ndarray

    @ndarray.setter
    def ndarray(self, ndarray):
        """Sets the ndarray of this Base64NDArrayBodyKNN.

        the array to run the search on. Note that this must be a row vector  # noqa: E501

        :param ndarray: The ndarray of this Base64NDArrayBodyKNN.  # noqa: E501
        :type: str
        """

        self._ndarray = ndarray

    @property
    def k(self):
        """Gets the k of this Base64NDArrayBodyKNN.  # noqa: E501

        the number of results to retrieve  # noqa: E501

        :return: The k of this Base64NDArrayBodyKNN.  # noqa: E501
        :rtype: int
        """
        return self._k

    @k.setter
    def k(self, k):
        """Sets the k of this Base64NDArrayBodyKNN.

        the number of results to retrieve  # noqa: E501

        :param k: The k of this Base64NDArrayBodyKNN.  # noqa: E501
        :type: int
        """

        self._k = k

    @property
    def force_fill_k(self):
        """Gets the force_fill_k of this Base64NDArrayBodyKNN.  # noqa: E501

        If 'True' it will brute force search for running search relative to a target but forced to fill the result list until the desired k is matched.  # noqa: E501

        :return: The force_fill_k of this Base64NDArrayBodyKNN.  # noqa: E501
        :rtype: bool
        """
        return self._force_fill_k

    @force_fill_k.setter
    def force_fill_k(self, force_fill_k):
        """Sets the force_fill_k of this Base64NDArrayBodyKNN.

        If 'True' it will brute force search for running search relative to a target but forced to fill the result list until the desired k is matched.  # noqa: E501

        :param force_fill_k: The force_fill_k of this Base64NDArrayBodyKNN.  # noqa: E501
        :type: bool
        """

        self._force_fill_k = force_fill_k

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Base64NDArrayBodyKNN):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FeedbackResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'retrain_threshold': 'int',
        'accumulated_so_far': 'int'
    }

    attribute_map = {
        'retrain_threshold': 'retrainThreshold',
        'accumulated_so_far': 'accumulatedSoFar'
    }

    def __init__(self, retrain_threshold=None, accumulated_so_far=None):  # noqa: E501
        """FeedbackResponse - a model defined in Swagger"""  # noqa: E501

        self._retrain_threshold = None
        self._accumulated_so_far = None
        self.discriminator = None

        if retrain_threshold is not None:
            self.retrain_threshold = retrain_threshold
        if accumulated_so_far is not None:
            self.accumulated_so_far = accumulated_so_far

    @property
    def retrain_threshold(self):
        """Gets the retrain_threshold of this FeedbackResponse.  # noqa: E501

        The number of examples required to start the retraining process.  # noqa: E501

        :return: The retrain_threshold of this FeedbackResponse.  # noqa: E501
        :rtype: int
        """
        return self._retrain_threshold

    @retrain_threshold.setter
    def retrain_threshold(self, retrain_threshold):
        """Sets the retrain_threshold of this FeedbackResponse.

        The number of examples required to start the retraining process.  # noqa: E501

        :param retrain_threshold: The retrain_threshold of this FeedbackResponse.  # noqa: E501
        :type: int
        """

        self._retrain_threshold = retrain_threshold

    @property
    def accumulated_so_far(self):
        """Gets the accumulated_so_far of this FeedbackResponse.  # noqa: E501

        The number of retraining examples accumulated so far.  # noqa: E501

        :return: The accumulated_so_far of this FeedbackResponse.  # noqa: E501
        :rtype: int
        """
        return self._accumulated_so_far

    @accumulated_so_far.setter
    def accumulated_so_far(self, accumulated_so_far):
        """Sets the accumulated_so_far of this FeedbackResponse.

        The number of retraining examples accumulated so far.  # noqa: E501

        :param accumulated_so_far: The accumulated_so_far of this FeedbackResponse.  # noqa: E501
        :type: int
        """

        self._accumulated_so_far = accumulated_so_far

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedbackResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'group_id': 'int',
        'group_name': 'str',
        'added': 'int',
        'updated': 'int'
    }

    attribute_map = {
        'group_id': 'groupId',
        'group_name': 'groupName',
        'added': 'added',
        'updated': 'updated'
    }

    def __init__(self, group_id=None, group_name=None, added=None, updated=None):  # noqa: E501
        """ResourceGroup - a model defined in Swagger"""  # noqa: E501

        self._group_id = None
        self._group_name = None
        self._added = None
        self._updated = None
        self.discriminator = None

        if group_id is not None:
            self.group_id = group_id
        if group_name is not None:
            self.group_name = group_name
        if added is not None:
            self.added = added
        if updated is not None:
            self.updated = updated

    @property
    def group_id(self):
        """Gets the group_id of this ResourceGroup.  # noqa: E501

        ID of the resource group  # noqa: E501

        :return: The group_id of this ResourceGroup.  # noqa: E501
        :rtype: int
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this ResourceGroup.

        ID of the resource group  # noqa: E501

        :param group_id: The group_id of this ResourceGroup.  # noqa: E501
        :type: int
        """

        self._group_id = group_id

    @property
    def group_name(self):
        """Gets the group_name of this ResourceGroup.  # noqa: E501

        Name of the resource group  # noqa: E501

        :return: The group_name of this ResourceGroup.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this ResourceGroup.

        Name of the resource group  # noqa: E501

        :param group_name: The group_name of this ResourceGroup.  # noqa: E501
        :type: str
        """

        self._group_name = group_name

    @property
    def added(self):
        """Gets the added of this ResourceGroup.  # noqa: E501

        Milliseconds in Long when the resource group was added  # noqa: E501

        :return: The added of this ResourceGroup.  # noqa: E501
        :rtype: int
        """
        return self._added

    @added.setter
    def added(self, added):
        """Sets the added of this ResourceGroup.

        Milliseconds in Long when the resource group was added  # noqa: E501

        :param added: The added of this ResourceGroup.  # noqa: E501
        :type: int
        """

        self._added = added

    @property
    def updated(self):
        """Gets the updated of this ResourceGroup.  # noqa: E501

        Milliseconds in Long when the resource group was updated  # noqa: E501

        :return: The updated of this ResourceGroup.  # noqa: E501
        :rtype: int
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ResourceGroup.

        Milliseconds in Long when the resource group was updated  # noqa: E501

        :param updated: The updated of this ResourceGroup.  # noqa: E501
        :type: int
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class INDArray(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'array': 'str',
        'shape': 'list[int]',
        'ordering': 'str',
        'data': 'list[float]',
        'data_type': 'str'
    }

    attribute_map = {
        'array': 'array',
        'shape': 'shape',
        'ordering': 'ordering',
        'data': 'data',
        'data_type': 'dataType'
    }

    def __init__(self, array=None, shape=None, ordering=None, data=None, data_type=None):  # noqa: E501
        """INDArray - a model defined in Swagger"""  # noqa: E501

        self._array = None
        self._shape = None
        self._ordering = None
        self._data = None
        self._data_type = None
        self.discriminator = None

        if array is not None:
            self.array = array
        if shape is not None:
            self.shape = shape
        if ordering is not None:
            self.ordering = ordering
        if data is not None:
            self.data = data
        if data_type is not None:
            self.data_type = data_type

    @property
    def array(self):
        """Gets the array of this INDArray.  # noqa: E501


        :return: The array of this INDArray.  # noqa: E501
        :rtype: str
        """
        return self._array

    @array.setter
    def array(self, array):
        """Sets the array of this INDArray.


        :param array: The array of this INDArray.  # noqa: E501
        :type: str
        """

        self._array = array

    @property
    def shape(self):
        """Gets the shape of this INDArray.  # noqa: E501


        :return: The shape of this INDArray.  # noqa: E501
        :rtype: list[int]
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """Sets the shape of this INDArray.


        :param shape: The shape of this INDArray.  # noqa: E501
        :type: list[int]
        """

        self._shape = shape

    @property
    def ordering(self):
        """Gets the ordering of this INDArray.  # noqa: E501


        :return: The ordering of this INDArray.  # noqa: E501
        :rtype: str
        """
        return self._ordering

    @ordering.setter
    def ordering(self, ordering):
        """Sets the ordering of this INDArray.


        :param ordering: The ordering of this INDArray.  # noqa: E501
        :type: str
        """
        allowed_values = ["f", "c"]  # noqa: E501
        if ordering not in allowed_values:
            raise ValueError(
                "Invalid value for `ordering` ({0}), must be one of {1}"  # noqa: E501
                .format(ordering, allowed_values)
            )

        self._ordering = ordering

    @property
    def data(self):
        """Gets the data of this INDArray.  # noqa: E501


        :return: The data of this INDArray.  # noqa: E501
        :rtype: list[float]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this INDArray.


        :param data: The data of this INDArray.  # noqa: E501
        :type: list[float]
        """

        self._data = data

    @property
    def data_type(self):
        """Gets the data_type of this INDArray.  # noqa: E501


        :return: The data_type of this INDArray.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this INDArray.


        :param data_type: The data_type of this INDArray.  # noqa: E501
        :type: str
        """
        allowed_values = ["INT8", "UINT8", "INT16", "FLOAT16"]  # noqa: E501
        if data_type not in allowed_values:
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, INDArray):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import skil_client
from skil_client.models.emr_resource_details import EMRResourceDetails  # noqa: E501
from skil_client.rest import ApiException


class TestEMRResourceDetails(unittest.TestCase):
    """EMRResourceDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEMRResourceDetails(self):
        """Test EMRResourceDetails"""
        # FIXME: construct object with mandatory attributes with example values
        # model = skil_client.models.emr_resource_details.EMRResourceDetails()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LogRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'offset': 'int',
        'row_count': 'int',
        'head': 'bool'
    }

    attribute_map = {
        'offset': 'offset',
        'row_count': 'rowCount',
        'head': 'head'
    }

    def __init__(self, offset=None, row_count=None, head=None):  # noqa: E501
        """LogRequest - a model defined in Swagger"""  # noqa: E501

        self._offset = None
        self._row_count = None
        self._head = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if row_count is not None:
            self.row_count = row_count
        if head is not None:
            self.head = head

    @property
    def offset(self):
        """Gets the offset of this LogRequest.  # noqa: E501


        :return: The offset of this LogRequest.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this LogRequest.


        :param offset: The offset of this LogRequest.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def row_count(self):
        """Gets the row_count of this LogRequest.  # noqa: E501


        :return: The row_count of this LogRequest.  # noqa: E501
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        """Sets the row_count of this LogRequest.


        :param row_count: The row_count of this LogRequest.  # noqa: E501
        :type: int
        """

        self._row_count = row_count

    @property
    def head(self):
        """Gets the head of this LogRequest.  # noqa: E501


        :return: The head of this LogRequest.  # noqa: E501
        :rtype: bool
        """
        return self._head

    @head.setter
    def head(self, head):
        """Sets the head of this LogRequest.


        :param head: The head of this LogRequest.  # noqa: E501
        :type: bool
        """

        self._head = head

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExampleEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'example_id': 'str',
        'example_version': 'int',
        'row_number': 'int',
        'created': 'int',
        'mini_batch_id': 'str',
        'mini_batch_version': 'int'
    }

    attribute_map = {
        'example_id': 'exampleId',
        'example_version': 'exampleVersion',
        'row_number': 'rowNumber',
        'created': 'created',
        'mini_batch_id': 'miniBatchId',
        'mini_batch_version': 'miniBatchVersion'
    }

    def __init__(self, example_id=None, example_version=None, row_number=None, created=None, mini_batch_id=None, mini_batch_version=None):  # noqa: E501
        """ExampleEntity - a model defined in Swagger"""  # noqa: E501

        self._example_id = None
        self._example_version = None
        self._row_number = None
        self._created = None
        self._mini_batch_id = None
        self._mini_batch_version = None
        self.discriminator = None

        if example_id is not None:
            self.example_id = example_id
        if example_version is not None:
            self.example_version = example_version
        if row_number is not None:
            self.row_number = row_number
        if created is not None:
            self.created = created
        if mini_batch_id is not None:
            self.mini_batch_id = mini_batch_id
        if mini_batch_version is not None:
            self.mini_batch_version = mini_batch_version

    @property
    def example_id(self):
        """Gets the example_id of this ExampleEntity.  # noqa: E501

        the GUID of the example  # noqa: E501

        :return: The example_id of this ExampleEntity.  # noqa: E501
        :rtype: str
        """
        return self._example_id

    @example_id.setter
    def example_id(self, example_id):
        """Sets the example_id of this ExampleEntity.

        the GUID of the example  # noqa: E501

        :param example_id: The example_id of this ExampleEntity.  # noqa: E501
        :type: str
        """

        self._example_id = example_id

    @property
    def example_version(self):
        """Gets the example_version of this ExampleEntity.  # noqa: E501

        Example version  # noqa: E501

        :return: The example_version of this ExampleEntity.  # noqa: E501
        :rtype: int
        """
        return self._example_version

    @example_version.setter
    def example_version(self, example_version):
        """Sets the example_version of this ExampleEntity.

        Example version  # noqa: E501

        :param example_version: The example_version of this ExampleEntity.  # noqa: E501
        :type: int
        """

        self._example_version = example_version

    @property
    def row_number(self):
        """Gets the row_number of this ExampleEntity.  # noqa: E501

        Row Number  # noqa: E501

        :return: The row_number of this ExampleEntity.  # noqa: E501
        :rtype: int
        """
        return self._row_number

    @row_number.setter
    def row_number(self, row_number):
        """Sets the row_number of this ExampleEntity.

        Row Number  # noqa: E501

        :param row_number: The row_number of this ExampleEntity.  # noqa: E501
        :type: int
        """

        self._row_number = row_number

    @property
    def created(self):
        """Gets the created of this ExampleEntity.  # noqa: E501

        when the example was created  # noqa: E501

        :return: The created of this ExampleEntity.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ExampleEntity.

        when the example was created  # noqa: E501

        :param created: The created of this ExampleEntity.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def mini_batch_id(self):
        """Gets the mini_batch_id of this ExampleEntity.  # noqa: E501

        The GUID of the minibatch  # noqa: E501

        :return: The mini_batch_id of this ExampleEntity.  # noqa: E501
        :rtype: str
        """
        return self._mini_batch_id

    @mini_batch_id.setter
    def mini_batch_id(self, mini_batch_id):
        """Sets the mini_batch_id of this ExampleEntity.

        The GUID of the minibatch  # noqa: E501

        :param mini_batch_id: The mini_batch_id of this ExampleEntity.  # noqa: E501
        :type: str
        """

        self._mini_batch_id = mini_batch_id

    @property
    def mini_batch_version(self):
        """Gets the mini_batch_version of this ExampleEntity.  # noqa: E501

        minibatch version  # noqa: E501

        :return: The mini_batch_version of this ExampleEntity.  # noqa: E501
        :rtype: int
        """
        return self._mini_batch_version

    @mini_batch_version.setter
    def mini_batch_version(self, mini_batch_version):
        """Sets the mini_batch_version of this ExampleEntity.

        minibatch version  # noqa: E501

        :param mini_batch_version: The mini_batch_version of this ExampleEntity.  # noqa: E501
        :type: int
        """

        self._mini_batch_version = mini_batch_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExampleEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
